@@ -37,7 +37,7 @@
 
 #include "LilyPondExporter.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "document/ConfigGroups.h"
@@ -66,14 +66,14 @@
 #include "gui/editors/guitar/Chord.h"
 #include "gui/general/ProgressReporter.h"
 #include "gui/widgets/CurrentProgressDialog.h"
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
 #include <tqfileinfo.h>
 #include <tqobject.h>
 #include <tqregexp.h>
 #include <tqstring.h>
 #include <tqtextcodec.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <sstream>
 #include <algorithm>
 
@@ -122,7 +122,7 @@ void
 LilyPondExporter::readConfigVariables(void)
 {
     // grab config info
-    KConfig *cfg = kapp->config();
+    TDEConfig *cfg = kapp->config();
     cfg->setGroup(NotationViewConfigGroup);
 
     m_paperSize = cfg->readUnsignedNumEntry("lilypapersize", PAPER_A4);
