@@ -24,11 +24,11 @@
 
 
 #include "RosegardenGUIView.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include "sound/Midi.h"
 #include "gui/editors/segment/TrackButtons.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "document/ConfigGroups.h"
@@ -80,8 +80,8 @@
 #include "sound/AudioFileManager.h"
 #include "sound/MappedEvent.h"
 #include <kcommand.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
 #include <kprocess.h>
 #include <tqapplication.h>
 #include <tqcursor.h>
@@ -347,7 +347,7 @@ void RosegardenGUIView::slotEditSegment(Segment* segment)
         slotEditSegmentAudio(segment);
     } else {
 
-        KConfig* config = kapp->config();
+        TDEConfig* config = kapp->config();
         config->setGroup(GeneralOptionsConfigGroup);
         GeneralConfigurationPage::DoubleClickClient
         client =
@@ -830,7 +830,7 @@ void RosegardenGUIView::slotEditSegmentAudio(Segment *segment)
     std::cout << "RosegardenGUIView::slotEditSegmentAudio() - "
     << "starting external audio editor" << std::endl;
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup(GeneralOptionsConfigGroup);
 
     TQString application = config->readEntry("externalaudioeditor", "");
@@ -874,7 +874,7 @@ void RosegardenGUIView::slotEditSegmentAudio(Segment *segment)
 
     // Prepare the process
     //
-    KProcess *process = new KProcess();
+    TDEProcess *process = new TDEProcess();
     (*process) << splitCommand;
     (*process) << TQString(aF->getFilename().c_str());
 
@@ -1731,7 +1731,7 @@ RosegardenGUIView::slotUpdateRecordingSegment(Segment *segment,
         return ;
     lastRecordingSegment = segment;
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup(GeneralOptionsConfigGroup);
 
     int tracking = config->readUnsignedNumEntry("recordtracking", 0);
