@@ -20,21 +20,21 @@
 */
 
 #include <tqtimer.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <sys/time.h>
 #include <unistd.h>
 #include "base/RealTime.h"
 
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
-#include <klocale.h>
+#include <tdecmdlineargs.h>
+#include <tdeaboutdata.h>
+#include <tdelocale.h>
 #include <dcopclient.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
 #include <kstddirs.h>
 #include <ktip.h>
 #include <kprocess.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 
 #include <tqstringlist.h>
 #include <tqregexp.h>
@@ -47,7 +47,7 @@
 #include "gui/application/RosegardenGUIApp.h"
 #include "gui/widgets/CurrentProgressDialog.h"
 #include "document/RosegardenGUIDoc.h"
-#include "gui/kdeext/KStartupLogo.h"
+#include "gui/kdeext/TDEStartupLogo.h"
 
 #include "gui/application/RosegardenApplication.h"
 #include "gui/application/RosegardenDCOP.h"
@@ -311,7 +311,7 @@ visible at the bottom of rosegarden/sequencer/main.cpp.
 static const char *description =
     I18N_NOOP("Rosegarden - A sequencer and musical notation editor");
 
-static KCmdLineOptions options[] =
+static TDECmdLineOptions options[] =
     {
         { "nosequencer", I18N_NOOP("Don't use the sequencer (support editing only)"), 0 },
         { "nosplash", I18N_NOOP("Don't show the splash screen"), 0 },
@@ -370,7 +370,7 @@ void testInstalledVersion()
         (0,
          i18n("Installation contains the wrong version of Rosegarden."),
          i18n(" The wrong versions of Rosegarden's data files were\n"
-              " found in the standard KDE installation directories.\n"
+              " found in the standard TDE installation directories.\n"
               " (I am %1, but the installed files are for version %2.)\n\n"
               " This may mean one of the following:\n\n"
               " 1. This is a new upgrade of Rosegarden, and it has not yet been\n"
@@ -379,7 +379,7 @@ void testInstalledVersion()
               "     successfully.\n\n"
               " 2. The upgrade was installed in a non-standard directory,\n"
               "     and an old version was found in a standard directory.  If so,\n"
-              "     you will need to add the correct directory to your KDEDIRS\n"
+              "     you will need to add the correct directory to your TDEDIRS\n"
               "     environment variable before you can run it.").arg(VERSION).arg(installedVersion),
          i18n("Installation problem"));
 
@@ -389,13 +389,13 @@ void testInstalledVersion()
         (0,
          i18n("Rosegarden does not appear to have been installed."),
          i18n(" One or more of Rosegarden's data files could not be\n"
-              " found in the standard KDE installation directories.\n\n"
+              " found in the standard TDE installation directories.\n\n"
               " This may mean one of the following:\n\n"
               " 1. Rosegarden has not been correctly installed.  If you compiled\n"
               "     it yourself, check that you have run \"make install\" and that\n"
               "     the procedure completed successfully.\n\n"
               " 2. Rosegarden has been installed in a non-standard directory,\n"
-              "     and you need to add this directory to your KDEDIRS environment\n"
+              "     and you need to add this directory to your TDEDIRS environment\n"
               "     variable before you can run it.  This may be the case if you\n"
               "     installed into $HOME or a local third-party package directory\n"
               "     like /usr/local or /opt."),
@@ -412,8 +412,8 @@ int main(int argc, char *argv[])
 
     srandom((unsigned int)time(0) * (unsigned int)getpid());
 
-    KAboutData aboutData( "rosegarden", I18N_NOOP("Rosegarden"),
-                          VERSION, description, KAboutData::License_GPL,
+    TDEAboutData aboutData( "rosegarden", I18N_NOOP("Rosegarden"),
+                          VERSION, description, TDEAboutData::License_GPL,
                           I18N_NOOP("Copyright 2000 - 2008 Guillaume Laurent, Chris Cannam, Richard Bown\nParts copyright 1994 - 2004 Chris Cannam, Andy Green, Richard Bown, Guillaume Laurent\nLilyPond fonts copyright 1997 - 2005 Han-Wen Nienhuys and Jan Nieuwenhuizen"),
                           0,
                           "http://www.rosegardenmusic.com/",
@@ -468,8 +468,8 @@ int main(int argc, char *argv[])
 
     aboutData.setTranslator(I18N_NOOP("_: NAME OF TRANSLATORS\nYour names") , I18N_NOOP("_: EMAIL OF TRANSLATORS\nYour emails"));
 
-    KCmdLineArgs::init( argc, argv, &aboutData );
-    KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
+    TDECmdLineArgs::init( argc, argv, &aboutData );
+    TDECmdLineArgs::addCmdLineOptions( options ); // Add our own options.
     KUniqueApplication::addCmdLineOptions(); // Add KUniqueApplication options.
 
     if (!RosegardenApplication::start())
@@ -487,7 +487,7 @@ int main(int argc, char *argv[])
 
     // Parse cmd line args
     //
-    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
 
     if (!args->isSet("ignoreversion")) {
         // Give up immediately if we haven't been installed or if the
@@ -496,7 +496,7 @@ int main(int argc, char *argv[])
         testInstalledVersion();
     }
 
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
 
     config->setGroup(GeneralOptionsConfigGroup);
     TQString lastVersion = config->readEntry("lastversion", "");
@@ -509,7 +509,7 @@ int main(int argc, char *argv[])
     // If there is no config setting for the startup window size, set
     // one now.  But base the default on the appropriate desktop size
     // (i.e. not the entire desktop, if Xinerama is in use).  This is
-    // obtained from KGlobalSettings::desktopGeometry(), but we can't
+    // obtained from TDEGlobalSettings::desktopGeometry(), but we can't
     // give it a meaningful point to measure from at this stage so we
     // always use the "leftmost" display (point 0,0).
 
@@ -520,10 +520,10 @@ int main(int argc, char *argv[])
     config->setGroup("MainView");
     int windowWidth = 0, windowHeight = 0;
 
-    TQDesktopWidget *desktop = KApplication::desktop();
+    TQDesktopWidget *desktop = TDEApplication::desktop();
     if (desktop) {
 	TQRect totalRect(desktop->screenGeometry());
-	TQRect desktopRect = KGlobalSettings::desktopGeometry(TQPoint(0, 0));
+	TQRect desktopRect = TDEGlobalSettings::desktopGeometry(TQPoint(0, 0));
 	TQSize startupSize;
 	if (desktopRect.height() <= 800) {
 	    startupSize = TQSize((desktopRect.width() * 6) / 7,
@@ -554,13 +554,13 @@ int main(int argc, char *argv[])
     // (c) The KDevelop Development Team
     //
     config->setGroup(GeneralOptionsConfigGroup);
-    KStartupLogo* startLogo = 0L;
+    TDEStartupLogo* startLogo = 0L;
 
     // See if the config wants us to control JACK
     //
     if (config->readBoolEntry("Logo", true) && (!kapp->isRestored() && args->isSet("splash")) ) {
         RG_DEBUG << k_funcinfo << "Showing startup logo\n";
-        startLogo = KStartupLogo::getInstance();
+        startLogo = TDEStartupLogo::getInstance();
 	startLogo->setShowTip(!newVersion);
         startLogo->show();
     }
@@ -578,7 +578,7 @@ int main(int argc, char *argv[])
 
         // RESTORE(RosegardenGUIApp);
         int n = 1;
-        while (KMainWindow::canBeRestored(n)) {
+        while (TDEMainWindow::canBeRestored(n)) {
             // memory leak if more than one can be restored?
             RG_DEBUG << "Restoring from session - restoring app #" << n << endl;
             (rosegardengui = new RosegardenGUIApp)->restore(n);
@@ -659,12 +659,12 @@ int main(int argc, char *argv[])
         TQString soundFontPath = config->readEntry("soundfontpath", "");
         TQFileInfo sfxLoadInfo(sfxLoadPath), soundFontInfo(soundFontPath);
         if (sfxLoadInfo.isExecutable() && soundFontInfo.isReadable()) {
-            KProcess* sfxLoadProcess = new KProcess;
+            TDEProcess* sfxLoadProcess = new TDEProcess;
             (*sfxLoadProcess) << sfxLoadPath << soundFontPath;
             RG_DEBUG << "Starting sfxload : " << sfxLoadPath << " " << soundFontPath << endl;
 
-            TQObject::connect(sfxLoadProcess, TQT_SIGNAL(processExited(KProcess*)),
-                             &app, TQT_SLOT(sfxLoadExited(KProcess*)));
+            TQObject::connect(sfxLoadProcess, TQT_SIGNAL(processExited(TDEProcess*)),
+                             &app, TQT_SLOT(sfxLoadExited(TDEProcess*)));
 
             sfxLoadProcess->start();
         } else {
@@ -713,7 +713,7 @@ int main(int argc, char *argv[])
     }
 
     if (newVersion) {
-	KStartupLogo::hideIfStillThere();
+	TDEStartupLogo::hideIfStillThere();
 	CurrentProgressDialog::freeze();
 
 	KDialogBase *dialog = new KDialogBase(rosegardengui, "welcome",
