@@ -24,7 +24,7 @@
 
 
 #include "AudioManagerDialog.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include "base/Event.h"
 #include "misc/Debug.h"
@@ -53,20 +53,20 @@
 #include "sound/AudioFileManager.h"
 #include "sound/WAVAudioFile.h"
 #include "UnusedAudioSelectionDialog.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kcommand.h>
-#include <kfiledialog.h>
-#include <kglobal.h>
+#include <tdefiledialog.h>
+#include <tdeglobal.h>
 #include <klineeditdlg.h>
-#include <klistview.h>
-#include <kmainwindow.h>
-#include <kmessagebox.h>
+#include <tdelistview.h>
+#include <tdemainwindow.h>
+#include <tdemessagebox.h>
 #include <kstdaction.h>
 #include <kurl.h>
 #include <kxmlguiclient.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <tqaccel.h>
 #include <tqcstring.h>
 #include <tqdatastream.h>
@@ -95,7 +95,7 @@ const char* const AudioManagerDialog::m_listViewLayoutName = "AudioManagerDialog
 
 AudioManagerDialog::AudioManagerDialog(TQWidget *parent,
                                        RosegardenGUIDoc *doc):
-        KMainWindow(parent, "audioManagerDialog"),
+        TDEMainWindow(parent, "audioManagerDialog"),
         m_doc(doc),
         m_playingAudioFile(0),
         m_audioPlayingDialog(0),
@@ -126,49 +126,49 @@ AudioManagerDialog::AudioManagerDialog(TQWidget *parent,
     m_wrongSampleRates = new TQLabel(i18n("* Some audio files are encoded at a sample rate different from that of the JACK audio server.\nRosegarden will play them at the correct speed, but they will sound terrible.\nPlease consider resampling such files externally, or adjusting the sample rate of the JACK server."), box);
     m_wrongSampleRates->hide();
 
-    TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     TQIconSet icon(TQPixmap(pixmapDir + "/toolbar/transport-play.xpm"));
 
-    new KAction(i18n("&Add Audio File..."), "fileopen", 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Add Audio File..."), "document-open", 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotAdd()), actionCollection(), "add_audio");
 
-    new KAction(i18n("&Unload Audio File"), "editdelete", 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Unload Audio File"), "edit-delete", 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotRemove()),
                 actionCollection(), "remove_audio");
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/transport-play.xpm"));
-    new KAction(i18n("&Play Preview"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Play Preview"), icon, 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotPlayPreview()),
                 actionCollection(), "preview_audio");
 
     /*!!! Not actually implemented -- this never worked right!
-        new KAction(i18n("Re&label"), 0, 0, TQT_TQOBJECT(this),
+        new TDEAction(i18n("Re&label"), 0, 0, TQT_TQOBJECT(this),
     		TQT_SLOT(slotRename()), 
     		actionCollection(), "rename_audio");
     */
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/insert_audio_into_track.xpm"));
-    new KAction(i18n("&Insert into Selected Audio Track"),
+    new TDEAction(i18n("&Insert into Selected Audio Track"),
                 icon, 0, TQT_TQOBJECT(this), TQT_SLOT(slotInsert()),
                 actionCollection(), "insert_audio");
 
-    new KAction(i18n("Unload &all Audio Files"), 0, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Unload &all Audio Files"), 0, 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotRemoveAll()),
                 actionCollection(), "remove_all_audio");
 
-    new KAction(i18n("Unload all &Unused Audio Files"), 0, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Unload all &Unused Audio Files"), 0, 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotRemoveAllUnused()),
                 actionCollection(), "remove_all_unused_audio");
 
-    new KAction(i18n("&Delete Unused Audio Files..."), 0, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Delete Unused Audio Files..."), 0, 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotDeleteUnused()),
                 actionCollection(), "delete_unused_audio");
 
-    new KAction(i18n("&Export Audio File..."), "fileexport", 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Export Audio File..."), "fileexport", 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotExportAudio()),
                 actionCollection(), "export_audio");
 /*
-    new KAction(i18n("Distribute Audio on &MIDI"),
+    new TDEAction(i18n("Distribute Audio on &MIDI"),
                 0, 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotDistributeOnMidiSegment()),
                 actionCollection(),
@@ -1166,7 +1166,7 @@ AudioManagerDialog::closeEvent(TQCloseEvent *e)
 {
     RG_DEBUG << "AudioManagerDialog::closeEvent()\n";
     emit closing();
-    KMainWindow::closeEvent(e);
+    TDEMainWindow::closeEvent(e);
 }
 
 void
