@@ -25,7 +25,7 @@
 
 #include "TransportDialog.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
 #include "base/Composition.h"
 #include "base/NotationTypes.h"
@@ -37,8 +37,8 @@
 #include "gui/widgets/Label.h"
 #include "sound/MappedEvent.h"
 #include "document/ConfigGroups.h"
-#include <kconfig.h>
-#include <kglobal.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
 #include <tqaccel.h>
 #include <tqcolor.h>
 #include <tqcstring.h>
@@ -123,7 +123,7 @@ TransportDialog::TransportDialog(TQWidget *parent,
 // Disable the loop button if JACK transport enabled, because this
 // causes a nasty race condition, and it just seems our loops are not JACK compatible
 // #1240039 - DMM
-//    KConfig* config = rgapp->config();
+//    TDEConfig* config = rgapp->config();
 //    config->setGroup(SequencerOptionsConfigGroup);
 //    if (config->readBoolEntry("jacktransport", false))
 //    {
@@ -267,7 +267,7 @@ TransportDialog::TransportDialog(TQWidget *parent,
 TransportDialog::~TransportDialog()
 {
     if (isVisible()) {
-        KConfig* config = rgapp->config();
+        TDEConfig* config = rgapp->config();
         config->setGroup(GeneralOptionsConfigGroup);
         config->writeEntry("transportx", x());
         config->writeEntry("transporty", y());
@@ -306,7 +306,7 @@ TransportDialog::initModeMap()
 void
 TransportDialog::show()
 {
-    KConfig* config = rgapp->config();
+    TDEConfig* config = rgapp->config();
     config->setGroup(GeneralOptionsConfigGroup);
     int x = config->readNumEntry("transportx", -1);
     int y = config->readNumEntry("transporty", -1);
@@ -328,7 +328,7 @@ void
 TransportDialog::hide()
 {
     if (isVisible()) {
-        KConfig* config = rgapp->config();
+        TDEConfig* config = rgapp->config();
         config->setGroup(GeneralOptionsConfigGroup);
         config->writeEntry("transportx", x());
         config->writeEntry("transporty", y());
@@ -341,7 +341,7 @@ TransportDialog::loadPixmaps()
 {
     m_lcdList.clear();
     TQString fileName;
-    TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
 
     for (int i = 0; i < 10; i++) {
         fileName = TQString("%1/transport/led-%2.xpm").arg(pixmapDir).arg(i);
@@ -1033,7 +1033,7 @@ void
 TransportDialog::slotLoopButtonClicked()
 {
     // disable if JACK transport has been set #1240039 - DMM
-    //    KConfig* config = rgapp->config();
+    //    TDEConfig* config = rgapp->config();
     //    config->setGroup(SequencerOptionsConfigGroup);
     //    if (config->readBoolEntry("jacktransport", false))
     //    {
