@@ -82,7 +82,7 @@ class LevelInfo;
 class MatrixView : public EditView
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
     friend class MatrixSelector;
 
@@ -675,7 +675,7 @@ protected:
 // class NoteSender : public TQObject
 // {
 //     Q_OBJECT
-//     TQ_OBJECT
+//     
         
 // public:
 //     NoteSender(int i, int p) : m_insid(i), m_pitch(p) { }
