@@ -26,7 +26,7 @@
 #include "NotationSelector.h"
 #include "misc/Debug.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include "base/Event.h"
 #include "base/NotationTypes.h"
 #include "base/PropertyName.h"
@@ -48,7 +48,7 @@
 #include "NotationTool.h"
 #include "NotationView.h"
 #include "NotePixmapFactory.h"
-#include <kaction.h>
+#include <tdeaction.h>
 #include <tqapplication.h>
 #include <tqiconset.h>
 #include <tqrect.h>
@@ -80,58 +80,58 @@ NotationSelector::NotationSelector(NotationView* view)
     TQIconSet icon
     (NotePixmapFactory::toTQPixmap(NotePixmapFactory::
                                   makeToolbarPixmap("crotchet")));
-    new KToggleAction(i18n("Switch to Insert Tool"), icon, 0, this,
+    new TDEToggleAction(i18n("Switch to Insert Tool"), icon, 0, this,
                       TQT_SLOT(slotInsertSelected()), actionCollection(),
                       "insert");
 
-    new KAction(i18n("Switch to Erase Tool"), "eraser", 0, this,
+    new TDEAction(i18n("Switch to Erase Tool"), "eraser", 0, this,
                 TQT_SLOT(slotEraseSelected()), actionCollection(),
                 "erase");
 
     // (this crashed, and it might be superfluous with ^N anyway, so I'm
     // commenting it out, but leaving it here in case I change my mind about
     // fooling with it.)  (DMM)
-    //    new KAction(i18n("Normalize Rests"), 0, 0, this,
+    //    new TDEAction(i18n("Normalize Rests"), 0, 0, this,
     //                TQT_SLOT(slotCollapseRests()), actionCollection(),
     //                "collapse_rests");
 
-    new KAction(i18n("Collapse Rests"), 0, 0, this,
+    new TDEAction(i18n("Collapse Rests"), 0, 0, this,
                 TQT_SLOT(slotCollapseRestsHard()), actionCollection(),
                 "collapse_rests_aggressively");
 
-    new KAction(i18n("Respell as Flat"), 0, 0, this,
+    new TDEAction(i18n("Respell as Flat"), 0, 0, this,
                 TQT_SLOT(slotRespellFlat()), actionCollection(),
                 "respell_flat");
 
-    new KAction(i18n("Respell as Sharp"), 0, 0, this,
+    new TDEAction(i18n("Respell as Sharp"), 0, 0, this,
                 TQT_SLOT(slotRespellSharp()), actionCollection(),
                 "respell_sharp");
 
-    new KAction(i18n("Respell as Natural"), 0, 0, this,
+    new TDEAction(i18n("Respell as Natural"), 0, 0, this,
                 TQT_SLOT(slotRespellNatural()), actionCollection(),
                 "respell_natural");
 
-    new KAction(i18n("Collapse Notes"), 0, 0, this,
+    new TDEAction(i18n("Collapse Notes"), 0, 0, this,
                 TQT_SLOT(slotCollapseNotes()), actionCollection(),
                 "collapse_notes");
 
-    new KAction(i18n("Interpret"), 0, 0, this,
+    new TDEAction(i18n("Interpret"), 0, 0, this,
                 TQT_SLOT(slotInterpret()), actionCollection(),
                 "interpret");
 
-    new KAction(i18n("Move to Staff Above"), 0, 0, this,
+    new TDEAction(i18n("Move to Staff Above"), 0, 0, this,
                 TQT_SLOT(slotStaffAbove()), actionCollection(),
                 "move_events_up_staff");
 
-    new KAction(i18n("Move to Staff Below"), 0, 0, this,
+    new TDEAction(i18n("Move to Staff Below"), 0, 0, this,
                 TQT_SLOT(slotStaffBelow()), actionCollection(),
                 "move_events_down_staff");
 
-    new KAction(i18n("Make Invisible"), 0, 0, this,
+    new TDEAction(i18n("Make Invisible"), 0, 0, this,
                 TQT_SLOT(slotMakeInvisible()), actionCollection(),
                 "make_invisible");
 
-    new KAction(i18n("Make Visible"), 0, 0, this,
+    new TDEAction(i18n("Make Visible"), 0, 0, this,
                 TQT_SLOT(slotMakeVisible()), actionCollection(),
                 "make_visible");
 
