@@ -25,9 +25,9 @@
 
 #include "NotationStaff.h"
 #include "misc/Debug.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Strings.h"
 #include "document/ConfigGroups.h"
 #include "base/Composition.h"
@@ -62,8 +62,8 @@
 #include "NotePixmapFactory.h"
 #include "NotePixmapParameters.h"
 #include "NoteStyleFactory.h"
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
 #include <tqcanvas.h>
 #include <tqpainter.h>
 #include <tqpoint.h>
@@ -98,7 +98,7 @@ NotationStaff::NotationStaff(TQCanvas *canvas, Segment *segment,
         m_ready(false),
         m_lastRenderedBar(0)
 {
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(NotationViewConfigGroup);
     m_colourQuantize = config->readBoolEntry("colourquantize", false);
 
@@ -433,7 +433,7 @@ NotationStaff::getNoteNameAtCanvasCoords(double x, int y,
     ::Rosegarden::Key key;
     getClefAndKeyAtCanvasCoords(x, y, clef, key);
 
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(GeneralOptionsConfigGroup);
     int baseOctave = config->readNumEntry("midipitchoctave", -2);
 
@@ -917,7 +917,7 @@ NotationStaff::renderSingleElement(ViewElementList::iterator &vli,
             <Bool>(BaseProperties::INVISIBLE, invisible) && invisible) {
         if (m_printPainter)
             return ;
-        KConfig *config = kapp->config();
+        TDEConfig *config = kapp->config();
         config->setGroup("Notation Options");
         bool showInvisibles = config->readBoolEntry("showinvisibles", true);
         if (!showInvisibles)
