@@ -26,12 +26,12 @@
 #include "NoteFontMap.h"
 #include "misc/Debug.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
 #include "misc/Strings.h"
 #include "base/Exception.h"
 #include "SystemFont.h"
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <tqfile.h>
 #include <tqfileinfo.h>
 #include <tqpixmap.h>
@@ -52,7 +52,7 @@ NoteFontMap::NoteFontMap(std::string name) :
         m_errorString(i18n("unknown error")),
         m_ok(true)
 {
-    m_fontDirectory = KGlobal::dirs()->findResource("appdata", "fonts/");
+    m_fontDirectory = TDEGlobal::dirs()->findResource("appdata", "fonts/");
 
     TQString mapFileName;
 
@@ -785,11 +785,11 @@ const
 {
     SymbolDataMap::const_iterator i = m_data.find(charName);
     if (i == m_data.end())
-        return false;
+        return 0;
 
     SizeDataMap::const_iterator si = m_sizes.find(size);
     if (si == m_sizes.end())
-        return false;
+        return 0;
 
     int fontId = i->second.getFontId();
 
@@ -802,7 +802,7 @@ const
 
     SystemFontNameMap::const_iterator fni = m_systemFontNames.find(fontId);
     if (fontId < 0 || fni == m_systemFontNames.end())
-        return false;
+        return 0;
     TQString fontName = fni->second;
 
     CharBaseMap::const_iterator bi = m_bases.find(fontId);
