@@ -25,9 +25,9 @@
 
 #include "SegmentParameterBox.h"
 #include <tqlayout.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "document/ConfigGroups.h"
@@ -58,7 +58,7 @@
 #include <kcolordialog.h>
 #include <kcombobox.h>
 #include <kcommand.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <klineeditdlg.h>
 #include <ktabwidget.h>
 #include <tqbutton.h>
@@ -1013,7 +1013,7 @@ SegmentParameterBox::updateHighLow()
     Pitch highest(m_highestPlayable, accidental);
     Pitch lowest(m_lowestPlayable, accidental);
 
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(GeneralOptionsConfigGroup);
     int base = config->readNumEntry("midipitchoctave", -2);
     //!!! FIXME this code is broken, and needs to be fixed after the fashion of
