@@ -26,14 +26,14 @@
 
 namespace Rosegarden {
 
-PlayListViewItem::PlayListViewItem(KListView* parent, KURL kurl)
-    : KListViewItem(parent, kurl.fileName(), kurl.prettyURL()),
+PlayListViewItem::PlayListViewItem(TDEListView* parent, KURL kurl)
+    : TDEListViewItem(parent, kurl.fileName(), kurl.prettyURL()),
       m_kurl(kurl)
 {
 }
 
-PlayListViewItem::PlayListViewItem(KListView* parent, TQListViewItem* after, KURL kurl)
-    : KListViewItem(parent, after, kurl.fileName(), kurl.prettyURL()),
+PlayListViewItem::PlayListViewItem(TDEListView* parent, TQListViewItem* after, KURL kurl)
+    : TDEListViewItem(parent, after, kurl.fileName(), kurl.prettyURL()),
       m_kurl(kurl)
 {
 }
