@@ -26,7 +26,7 @@
 #include "TrackButtons.h"
 #include <tqlayout.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
@@ -47,9 +47,9 @@
 #include "sound/PluginIdentifier.h"
 #include "TrackLabel.h"
 #include "TrackVUMeter.h"
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kled.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <tqcursor.h>
 #include <tqframe.h>
 #include <tqiconset.h>
@@ -644,7 +644,7 @@ TrackButtons::populateInstrumentPopup(Instrument *thisTrackInstr, TQPopupMenu* i
     if (!havePixmaps) {
 
         TQString pixmapDir =
-            KGlobal::dirs()->findResource("appdata", "pixmaps/");
+            TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
 
         connectedPixmap.load
             (TQString("%1/misc/connected.xpm").arg(pixmapDir));
