@@ -46,7 +46,7 @@
 #include "SegmentSelector.h"
 #include "SegmentToolBox.h"
 #include "SegmentTool.h"
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <tqbrush.h>
 #include <tqcolor.h>
 #include <tqevent.h>
@@ -63,8 +63,8 @@
 #include <tqsize.h>
 #include <tqstring.h>
 #include <tqwidget.h>
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <algorithm>
 
 
@@ -89,7 +89,7 @@ protected:
 CompositionView::CompositionView(RosegardenGUIDoc* doc,
                                  CompositionModel* model,
                                  TQWidget * parent, const char * name, WFlags f)
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,2,0)
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,2,0)
         : RosegardenScrollView(parent, name, f | WNoAutoErase | WStaticContents),
 #else
         :
@@ -309,7 +309,7 @@ void CompositionView::updateSelectionContents()
 
 void CompositionView::slotContentsMoving(int x, int y)
 {
-    //     qDebug("contents moving : x=%d", x);
+    //     tqDebug("contents moving : x=%d", x);
 }
 
 void CompositionView::slotSetTool(const TQString& toolName)
