@@ -26,7 +26,7 @@
 #include "SegmentSelector.h"
 
 #include "base/Event.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Debug.h"
 #include "base/Composition.h"
 #include "base/RealTime.h"
@@ -46,8 +46,8 @@
 #include "SegmentResizer.h"
 #include "SegmentTool.h"
 #include "SegmentToolBox.h"
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <tqcursor.h>
 #include <tqevent.h>
 #include <tqpoint.h>
