@@ -25,9 +25,9 @@
 
 #include "EditViewBase.h"
 #include <tqlayout.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
 #include "misc/Debug.h"
 #include "base/Clipboard.h"
@@ -44,16 +44,16 @@
 #include "gui/dialogs/TimeDialog.h"
 #include "gui/general/EditViewTimeSigNotifier.h"
 #include "gui/kdeext/KTmpStatusMsg.h"
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kcommand.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdockwidget.h>
 #include <kedittoolbar.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kkeydialog.h>
-#include <kmainwindow.h>
+#include <tdemainwindow.h>
 #include <kstatusbar.h>
-#include <kstdaccel.h>
+#include <tdestdaccel.h>
 #include <kstdaction.h>
 #include <kxmlguiclient.h>
 #include <tqaccel.h>
@@ -187,49 +187,49 @@ void EditViewBase::setupActions(TQString rcFileName, bool haveClipboard)
         KStdAction::paste (TQT_TQOBJECT(this), TQT_SLOT(slotEditPaste()), actionCollection());
     }
 
-    new KToolBarPopupAction(i18n("Und&o"),
-                            "undo",
-                            KStdAccel::key(KStdAccel::Undo),
+    new TDEToolBarPopupAction(i18n("Und&o"),
+                            "edit-undo",
+                            TDEStdAccel::key(TDEStdAccel::Undo),
                             actionCollection(),
                             KStdAction::stdName(KStdAction::Undo));
 
-    new KToolBarPopupAction(i18n("Re&do"),
-                            "redo",
-                            KStdAccel::key(KStdAccel::Redo),
+    new TDEToolBarPopupAction(i18n("Re&do"),
+                            "edit-redo",
+                            TDEStdAccel::key(TDEStdAccel::Redo),
                             actionCollection(),
                             KStdAction::stdName(KStdAction::Redo));
 
-    TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
 
     TQCanvasPixmap pixmap(pixmapDir + "/toolbar/matrix.png");
     TQIconSet icon = TQIconSet(pixmap);
-    new KAction(i18n("Open in Matri&x Editor"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Open in Matri&x Editor"), icon, 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotOpenInMatrix()), actionCollection(),
                 "open_in_matrix");
 
     pixmap.load(pixmapDir + "/toolbar/matrix-percussion.png");
     icon = TQIconSet(pixmap);
-    new KAction(i18n("Open in &Percussion Matrix Editor"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Open in &Percussion Matrix Editor"), icon, 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotOpenInPercussionMatrix()), actionCollection(),
                 "open_in_percussion_matrix");
 
     pixmap.load(pixmapDir + "/toolbar/notation.png");
     icon = TQIconSet(pixmap);
-    new KAction(i18n("Open in &Notation Editor"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Open in &Notation Editor"), icon, 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotOpenInNotation()), actionCollection(),
                 "open_in_notation");
 
     pixmap.load(pixmapDir + "/toolbar/eventlist.png");
     icon = TQIconSet(pixmap);
-    new KAction(i18n("Open in &Event List Editor"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Open in &Event List Editor"), icon, 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotOpenInEventList()), actionCollection(),
                 "open_in_event_list");
 
-    new KAction(i18n("Set Segment Start Time..."), 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Set Segment Start Time..."), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotSetSegmentStartTime()), actionCollection(),
                 "set_segment_start");
 
-    new KAction(i18n("Set Segment Duration..."), 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Set Segment Duration..."), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotSetSegmentDuration()), actionCollection(),
                 "set_segment_duration");
 
@@ -418,7 +418,7 @@ void EditViewBase::paintEvent(TQPaintEvent* e)
     }
 
     if (e)
-        KMainWindow::paintEvent(e);
+        TDEMainWindow::paintEvent(e);
 
     // moved this to the end of the method so that things called
     // from this method can still test whether the composition had
@@ -446,7 +446,7 @@ void EditViewBase::closeEvent(TQCloseEvent* e)
         RG_DEBUG << "EditViewBase::closeEvent() : is in ctor, ignoring close event\n";
         e->ignore();
     } else {
-        KMainWindow::closeEvent(e);
+        TDEMainWindow::closeEvent(e);
     }
 }
 
@@ -553,7 +553,7 @@ bool EditViewBase::getSegmentsOnlyRestsAndClefs()
 void EditViewBase::toggleWidget(TQWidget* widget,
                                 const TQString& toggleActionName)
 {
-    KToggleAction* toggleAction = getToggleAction(toggleActionName);
+    TDEToggleAction* toggleAction = getToggleAction(toggleActionName);
 
     if (!toggleAction) {
         RG_DEBUG << "!!! Unknown toggle action : " << toggleActionName << endl;
@@ -586,7 +586,7 @@ EditViewBase::slotTestClipboard()
 void
 EditViewBase::slotToggleSolo()
 {
-    KToggleAction* toggleSoloAction = getToggleAction("toggle_solo");
+    TDEToggleAction* toggleSoloAction = getToggleAction("toggle_solo");
     if (!toggleSoloAction)
         return ;
 
@@ -664,7 +664,7 @@ void EditViewBase::slotCompositionStateUpdate()
 {
     // update state of 'solo' toggle
     //
-    KToggleAction* toggleSolo = getToggleAction("toggle_solo");
+    TDEToggleAction* toggleSolo = getToggleAction("toggle_solo");
     if (!toggleSolo)
         return ;
 
@@ -702,9 +702,9 @@ MultiViewCommandHistory* EditViewBase::getCommandHistory()
     return getDocument()->getCommandHistory();
 }
 
-KToggleAction* EditViewBase::getToggleAction(const TQString& actionName)
+TDEToggleAction* EditViewBase::getToggleAction(const TQString& actionName)
 {
-    return dynamic_cast<KToggleAction*>(actionCollection()->action(actionName.ascii()));
+    return dynamic_cast<TDEToggleAction*>(actionCollection()->action(actionName.ascii()));
 }
 
 }
