@@ -25,7 +25,7 @@
 
 #include "TempoRuler.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
 #include "misc/Debug.h"
 #include "base/Composition.h"
@@ -40,8 +40,8 @@
 #include "gui/general/GUIPalette.h"
 #include "gui/widgets/TextFloat.h"
 #include "TempoColour.h"
-#include <kaction.h>
-#include <kglobal.h>
+#include <tdeaction.h>
+#include <tdeglobal.h>
 #include <kxmlguiclient.h>
 #include <kxmlguifactory.h>
 #include <tqcolor.h>
@@ -66,7 +66,7 @@ namespace Rosegarden
 
 TempoRuler::TempoRuler(RulerScale *rulerScale,
                        RosegardenGUIDoc *doc,
-                       KMainWindow *parentMainWindow,
+                       TDEMainWindow *parentMainWindow,
                        double xorigin,
                        int height,
                        bool small,
@@ -120,41 +120,41 @@ TempoRuler::TempoRuler(RulerScale *rulerScale,
     (doc->getCommandHistory(), TQT_SIGNAL(commandExecuted()),
      this, TQT_SLOT(update()));
 
-    TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     TQIconSet icon;
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/event-insert-tempo.png"));
-    new KAction(i18n("Insert Tempo Change"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Insert Tempo Change"), icon, 0, TQT_TQOBJECT(this),
                  TQT_SLOT(slotInsertTempoHere()), actionCollection(),
                  "insert_tempo_here");
 
-    new KAction(i18n("Insert Tempo Change at Playback Position"), 0, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Insert Tempo Change at Playback Position"), 0, 0, TQT_TQOBJECT(this),
                  TQT_SLOT(slotInsertTempoAtPointer()), actionCollection(),
                  "insert_tempo_at_pointer");
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/event-delete.png"));
-    new KAction(i18n("Delete Tempo Change"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Delete Tempo Change"), icon, 0, TQT_TQOBJECT(this),
                  TQT_SLOT(slotDeleteTempoChange()), actionCollection(),
                  "delete_tempo");
 
-    new KAction(i18n("Ramp Tempo to Next Tempo"), 0, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Ramp Tempo to Next Tempo"), 0, 0, TQT_TQOBJECT(this),
                  TQT_SLOT(slotRampToNext()), actionCollection(),
                  "ramp_to_next");
 
-    new KAction(i18n("Un-Ramp Tempo"), 0, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Un-Ramp Tempo"), 0, 0, TQT_TQOBJECT(this),
                  TQT_SLOT(slotUnramp()), actionCollection(),
                  "unramp");
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/event-edit.png"));
-    new KAction(i18n("Edit Tempo..."), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Edit Tempo..."), icon, 0, TQT_TQOBJECT(this),
                  TQT_SLOT(slotEditTempo()), actionCollection(),
                  "edit_tempo");
 
-    new KAction(i18n("Edit Time Signature..."), 0, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Edit Time Signature..."), 0, 0, TQT_TQOBJECT(this),
                  TQT_SLOT(slotEditTimeSignature()), actionCollection(),
                  "edit_time_signature");
 
-    new KAction(i18n("Open Tempo and Time Signature Editor"), 0, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Open Tempo and Time Signature Editor"), 0, 0, TQT_TQOBJECT(this),
                  TQT_SLOT(slotEditTempos()), actionCollection(),
                  "edit_tempos");
 
