@@ -30,7 +30,7 @@
 #include "AudioPluginOSCGUIManager.h"
 
 #include "sound/Midi.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "AudioPluginOSCGUI.h"
