@@ -44,15 +44,15 @@
 #include "gui/application/RosegardenApplication.h"
 #include "gui/dialogs/ExportDeviceDialog.h"
 #include "gui/dialogs/ImportDeviceDialog.h"
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
-#include <kaction.h>
-#include <kfiledialog.h>
-#include <kglobal.h>
-#include <kmainwindow.h>
-#include <kmessagebox.h>
-#include <kstdaccel.h>
+#include <tdeaction.h>
+#include <tdefiledialog.h>
+#include <tdeglobal.h>
+#include <tdemainwindow.h>
+#include <tdemessagebox.h>
+#include <tdestdaccel.h>
 #include <kstdaction.h>
 #include <tqcstring.h>
 #include <tqdatastream.h>
@@ -85,7 +85,7 @@ static const int RECORD_CONNECTION_COL = 2;
 
 DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
             RosegardenGUIDoc *document) :
-            KMainWindow(parent, "deviceeditordialog"),
+            TDEMainWindow(parent, "deviceeditordialog"),
             m_document(document),
             m_studio(&document->getStudio())
     {
@@ -214,7 +214,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
         layout->addWidget(closeButton);
         layout->addSpacing(5);
 
-        KAction* close = KStdAction::close(TQT_TQOBJECT(this),
+        TDEAction* close = KStdAction::close(TQT_TQOBJECT(this),
                                            TQT_SLOT(slotClose()),
                                            actionCollection());
 
@@ -224,15 +224,15 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
         mainLayout->addWidget(btnBox);
 
         // some adjustments
-        new KToolBarPopupAction(i18n("Und&o"),
-                                "undo",
-                                KStdAccel::shortcut(KStdAccel::Undo),
+        new TDEToolBarPopupAction(i18n("Und&o"),
+                                "edit-undo",
+                                TDEStdAccel::shortcut(TDEStdAccel::Undo),
                                 actionCollection(),
                                 KStdAction::stdName(KStdAction::Undo));
 
-        new KToolBarPopupAction(i18n("Re&do"),
-                                "redo",
-                                KStdAccel::shortcut(KStdAccel::Redo),
+        new TDEToolBarPopupAction(i18n("Re&do"),
+                                "edit-redo",
+                                TDEStdAccel::shortcut(TDEStdAccel::Redo),
                                 actionCollection(),
                                 KStdAction::stdName(KStdAction::Redo));
 
@@ -289,7 +289,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
     {
         DeviceList *devices = m_studio->getDevices();
 
-        //KConfig *config = kapp->config();
+        //TDEConfig *config = kapp->config();
         //config->setGroup(SequencerOptionsConfigGroup);
         //DeviceId recordDevice =
         //config->readUnsignedNumEntry("midirecorddevice");
@@ -456,7 +456,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
     DeviceManagerDialog::closeEvent(TQCloseEvent *e)
     {
         emit closing();
-        KMainWindow::closeEvent(e);
+        TDEMainWindow::closeEvent(e);
     }
 
     DeviceId
@@ -689,7 +689,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
         if (id == Device::NO_DEVICE)
             return ;
 
-        TQString deviceDir = KGlobal::dirs()->findResource("appdata", "library/");
+        TQString deviceDir = TDEGlobal::dirs()->findResource("appdata", "library/");
         TQDir dir(deviceDir);
         if (!dir.exists()) {
             deviceDir = ":ROSEGARDENDEVICE";
