@@ -27,7 +27,7 @@
 #include <tqlayout.h>
 
 #include "sound/Midi.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "base/Colour.h"
@@ -46,8 +46,8 @@
 #include "MixerWindow.h"
 #include "sound/MappedEvent.h"
 #include "StudioControl.h"
-#include <kaction.h>
-#include <kmainwindow.h>
+#include <tdeaction.h>
+#include <tdemainwindow.h>
 #include <kstdaction.h>
 #include <tqaccel.h>
 #include <tqcolor.h>
@@ -78,51 +78,51 @@ MidiMixerWindow::MidiMixerWindow(TQWidget *parent,
 
     TQIconSet icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                              ("transport-play")));
-    KAction *play = new KAction(i18n("&Play"), icon, Key_Enter, TQT_TQOBJECT(this),
+    TDEAction *play = new TDEAction(i18n("&Play"), icon, Key_Enter, TQT_TQOBJECT(this),
                 TQT_SIGNAL(play()), actionCollection(), "play");
     // Alternative shortcut for Play
-    KShortcut playShortcut = play->shortcut();
+    TDEShortcut playShortcut = play->shortcut();
     playShortcut.append( KKey(Key_Return + CTRL) );
     play->setShortcut(playShortcut);
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-stop")));
-    new KAction(i18n("&Stop"), icon, Key_Insert, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Stop"), icon, Key_Insert, TQT_TQOBJECT(this),
                 TQT_SIGNAL(stop()), actionCollection(), "stop");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-rewind")));
-    new KAction(i18n("Re&wind"), icon, Key_End, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Re&wind"), icon, Key_End, TQT_TQOBJECT(this),
                 TQT_SIGNAL(rewindPlayback()), actionCollection(),
                 "playback_pointer_back_bar");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-ffwd")));
-    new KAction(i18n("&Fast Forward"), icon, Key_PageDown, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Fast Forward"), icon, Key_PageDown, TQT_TQOBJECT(this),
                 TQT_SIGNAL(fastForwardPlayback()), actionCollection(),
                 "playback_pointer_forward_bar");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-rewind-end")));
-    new KAction(i18n("Rewind to &Beginning"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Rewind to &Beginning"), icon, 0, TQT_TQOBJECT(this),
                 TQT_SIGNAL(rewindPlaybackToBeginning()), actionCollection(),
                 "playback_pointer_start");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-ffwd-end")));
-    new KAction(i18n("Fast Forward to &End"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Fast Forward to &End"), icon, 0, TQT_TQOBJECT(this),
                 TQT_SIGNAL(fastForwardPlaybackToEnd()), actionCollection(),
                 "playback_pointer_end");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-record")));
-    new KAction(i18n("&Record"), icon, 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Record"), icon, 0, TQT_TQOBJECT(this),
                 TQT_SIGNAL(record()), actionCollection(),
                 "record");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-panic")));
-    new KAction(i18n("Panic"), icon, Key_P + CTRL + ALT, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Panic"), icon, Key_P + CTRL + ALT, TQT_TQOBJECT(this),
                 TQT_SIGNAL(panic()), actionCollection(),
                 "panic");
 
