@@ -26,7 +26,7 @@
 #include "TimeWidget.h"
 #include <tqlayout.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Debug.h"
 #include "base/Composition.h"
 #include "base/NotationTypes.h"
