@@ -23,7 +23,7 @@
 */
 
 #include "RosegardenSequencerApp.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -34,7 +34,7 @@
 
 #include <iostream>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
 
 #include <dcopclient.h>
@@ -77,7 +77,7 @@ RosegardenSequencerApp::RosegardenSequencerApp() :
         m_loopStart(0, 0),
         m_loopEnd(0, 0),
         m_studio(new MappedStudio()),
-        m_segmentFilesPath(KGlobal::dirs()->resourceDirs("tmp").last()),
+        m_segmentFilesPath(TDEGlobal::dirs()->resourceDirs("tmp").last()),
         m_metaIterator(0),
         m_controlBlockMmapper(0),
         m_transportToken(1),
@@ -567,7 +567,7 @@ RosegardenSequencerApp::processAsynchronousEvents()
         lastCheckedAt = tv;
 
         try {
-            m_controlBlockMmapper = new ControlBlockMmapper(KGlobal::dirs()->resourceDirs("tmp").last()
+            m_controlBlockMmapper = new ControlBlockMmapper(TDEGlobal::dirs()->resourceDirs("tmp").last()
                                     + "/rosegarden_control_block");
         } catch (Exception e) {
             // Assume that the control block simply hasn't been
@@ -839,7 +839,7 @@ RosegardenSequencerApp::play(const RealTime &time,
         mmapSegment(m_segmentFilesPath + "/" + segmentsDir[i]);
     }
 
-    TQString tmpDir = KGlobal::dirs()->resourceDirs("tmp").last();
+    TQString tmpDir = TDEGlobal::dirs()->resourceDirs("tmp").last();
 
     // Map metronome
     //
