@@ -27,13 +27,8 @@
 #include <cstdio>   // sprintf
 #include <cstdlib>
 #include <pthread.h>
-
-#if (__GNUC__ < 3)
-#include <strstream>
-#define stringstream strstream
-#else
 #include <sstream>
-#endif
+
 
 #include <kapp.h>
 #include <tdelocale.h>
